@@ -48,7 +48,7 @@ def format_stack2(formatter):
 
 def format_frame(formatter):
     frame = inspect.currentframe()
-    return list(formatter.format_frame(frame))
+    return formatter.format_frame(frame)
 
 
 def f_string():
@@ -61,6 +61,31 @@ def f_string():
     }"""
 
 
+def block_right():
+    nb = len(letter
+             for letter
+               in
+             "words")
+
+
+def block_left():
+    nb_characters = len(letter
+             for letter
+
+               in
+             "words")
+
+
+def blank_lines():
+    a = [1, 2, 3]
+
+    length = len(a)
+
+
+    return a[length]
+
+
+
 if __name__ == '__main__':
     try:
         bar()
